@@ -260,6 +260,11 @@ class Adafruit_BME680:
         calc_pres += (var1 + var2 + var3 + (self._pressure_calibration[6] * 128)) / 16
         return calc_pres / 100
 
+    @property
+    def relative_humidity(self):
+        """The relative humidity in RH %"""
+        return self.humidity
+
     @property
     def humidity(self):
         """The relative humidity in RH %"""
