@@ -16,9 +16,9 @@ bme680.sea_level_pressure = 1013.25
 temperature_offset = -5
 
 while True:
-    print("\nTemperature: %0.1f C" % bme680.temperature + temperature_offset)
+    print("\nTemperature: %0.1f C" % (bme680.temperature + temperature_offset))
     print("Gas: %d ohm" % bme680.gas)
-    print("Humidity: %0.1f %%" % bme680.humidity)
+    print("Humidity: %0.1f %%" % bme680.relative_humidity)
     print("Pressure: %0.3f hPa" % bme680.pressure)
     print("Altitude = %0.2f meters" % bme680.altitude)
 
